package lk.geniussoft.flutter.sunmi_printer_v2;

import android.content.Context;


import java.util.ArrayList;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * SunmiPrinterV2Plugin
 */
public class SunmiPrinterV2Plugin implements FlutterPlugin, MethodCallHandler {
    private MethodChannel channel;
    private Context context;
    private SunmiPrintHelper printer;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "sunmi_printer_v2");
        channel.setMethodCallHandler(this);
        this.context = flutterPluginBinding.getApplicationContext();
        SunmiPrintHelper.getInstance().initSunmiPrinterService(flutterPluginBinding.getApplicationContext());
        this.printer = SunmiPrintHelper.getInstance();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        switch (call.method) {
            case "getSerialNo":
                result.success(SunmiDeviceHelper.getSerialNumber());
                break;
            case "getPrinterSerialNo":
                result.success(this.printer.getPrinterSerialNo());
                break;
            case "getPrinterModel":
                result.success(this.printer.getDeviceModel());
                break;
            case "getPrinterVersion":
                result.success(this.printer.getPrinterVersion());
                break;
            case "getPrinterPaper":
                result.success(this.printer.getPrinterPaper());
                break;
            case "initPrinter":
                this.printer.initPrinter();
                result.success(null);
                break;
            case "feedPaper":
                this.printer.feedPaper();
                result.success(null);
                break;
            case "printText": {
                final String content = call.argument("content");
                final int size = call.argument("size");
                final boolean isBold = call.argument("isBold");
                final boolean isUnderline = call.argument("isUnderline");
                this.printer.printText(content, size, isBold, isUnderline);
                result.success(null);
            }
            break;
            case "setAlign": {
                final int alignment = call.argument("alignment");
                this.printer.setAlign(alignment);
                result.success(null);
            }
            break;
            case "setBold": {
                final boolean isBold = call.argument("isBold");
                this.printer.setBold(isBold);
                result.success(null);
            }
            break;
            case "setAntiWhite": {
                final boolean isAntiWhite = call.argument("isAntiWhite");
                this.printer.setAntiWhite(isAntiWhite);
                result.success(null);
            }
            break;
            case "setFontSize":
                final float fontSize = call.argument("fontSize");
                this.printer.setFontSize(fontSize);
                result.success(null);
                break;
            case "printBarcode": {
                final String barcode = call.argument("barcode");
                final int symbology = call.argument("type");
                final int height = call.argument("height");
                final int width = call.argument("width");
                final int textPosition = call.argument("textPosition");
                this.printer.printBarCode(barcode, symbology, height, width, textPosition);
                result.success(null);
            }
            break;
            case "printTable": {
                final ArrayList<String> texts = call.argument("texts");
                final int[] widths = call.argument("widths");
                final int[] alignments = call.argument("alignments");
                this.printer.printTable(texts.toArray(new String[0]), widths, alignments);
                result.success(null);
            }
            break;
            case "printLineDivider":
                this.printer.printLineDivider();
                result.success(null);
                break;
            case "lineWrap": {
                final int lines = call.argument("lines");
                this.printer.lineWrap(lines);
                result.success(null);
            }
            break;
            case "printSample":
                this.printer.printExample(this.context);
                result.success(null);
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
        this.printer.deInitSunmiPrinterService(this.context);
        this.printer = null;
    }
}
