import 'dart:async';
import 'dart:typed_data';

import 'package:flutter/services.dart';

class PrinterTextAlignment {
  const PrinterTextAlignment._(this.value);

  final int value;
  static const left = PrinterTextAlignment._(0);
  static const center = PrinterTextAlignment._(1);
  static const right = PrinterTextAlignment._(2);
}

class BarcodeType {
  const BarcodeType._(this.value);

  final int value;
  static const upc_a = BarcodeType._(0);
  static const upc_e = BarcodeType._(1);
  static const ean_13 = BarcodeType._(2);
  static const ean_8 = BarcodeType._(3);
  static const code_39 = BarcodeType._(4);
  static const itf = BarcodeType._(5);
  static const code_bar = BarcodeType._(6);
  static const code_93 = BarcodeType._(7);
  static const code_128 = BarcodeType._(8);
}

class BarcodeTextPosition {
  const BarcodeTextPosition._(this.value);

  final int value;
  static const noText = BarcodeTextPosition._(0);
  static const textAbove = BarcodeTextPosition._(1);
  static const textBelow = BarcodeTextPosition._(2);
  static const textAboveAndBelow = BarcodeTextPosition._(3);
}

class SunmiPrinterV2 {
  static const MethodChannel _channel = const MethodChannel('sunmi_printer_v2');

  static Future<String> get getSerialNo async {
    final String serialNo = await _channel.invokeMethod('getSerialNo');
    return serialNo;
  }

  static Future<String> get getPrinterSerialNo async {
    final String serialNo = await _channel.invokeMethod('getPrinterSerialNo');
    return serialNo;
  }

  static Future<String> get getPrinterModel async {
    final String model = await _channel.invokeMethod('getPrinterModel');
    return model;
  }

  static Future<String> get getPrinterVersion async {
    final String printerVersion =
        await _channel.invokeMethod('getPrinterVersion');
    return printerVersion;
  }

  static Future<String> get getPrinterPaper async {
    final String paper = await _channel.invokeMethod('getPrinterPaper');
    return paper;
  }

  static Future<void> initPrinter() async {
    await _channel.invokeMethod("initPrinter");
  }

  static Future<void> feedPaper() async {
    await _channel.invokeMethod("feedPaper");
  }

  static Future<void> printText(String content,
      {int size = 18, bool isBold = false, bool isUnderline: false}) async {
    await _channel.invokeMethod("printText", <String, dynamic>{
      'content': content,
      'size': size,
      'isBold': isBold,
      'isUnderline': isUnderline,
    });
  }

  static Future<void> setAlign(PrinterTextAlignment alignment) async {
    await _channel.invokeMethod("setAlign", <String, dynamic>{
      'alignment': alignment.value,
    });
  }

  static Future<void> setBold(bool isBold) async {
    await _channel.invokeMethod("setBold", <String, dynamic>{
      'isBold': isBold,
    });
  }

  static Future<void> setAntiWhite(bool isAntiWhite) async {
    await _channel.invokeMethod("setAntiWhite", <String, dynamic>{
      'isAntiWhite': isAntiWhite,
    });
  }

  static Future<void> printBarcode(
      {String barcode,
      BarcodeType type,
      int height = 30,
      int width = 3,
      BarcodeTextPosition textPosition = BarcodeTextPosition.noText}) async {
    await _channel.invokeMethod("printBarcode", <String, dynamic>{
      'barcode': barcode,
      "type": type.value,
      'textPosition': textPosition.value,
      'width': width,
      'height': height,
    });
  }

  static Future<void> printTable({
    List<String> texts,
    List<int> widths = const [1, 1],
    List<int> alignments = const [0, 2],
  }) async {
    await _channel.invokeMethod('printTable', <String, dynamic>{
      'texts': texts,
      "widths": Int32List.fromList(widths),
      "alignments": Int32List.fromList(alignments),
    });
  }

  static Future<void> printLineDivider() async {
    await _channel.invokeMethod("printLineDivider");
  }

  static Future<void> lineWrap({int lines = 1}) async {
    await _channel.invokeMethod("lineWrap", <String, dynamic>{
      "lines": lines,
    });
  }

  @deprecated
  static Future<void> printSample() async {
    await _channel.invokeMethod("printSample");
  }
}
